==> bea_flutter_package-1.2.0.tar.gz: lib/bea_services/core/bea_files_manager.dart <==
import 'dart:async';
import 'dart:io';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/error/bea_error.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/file/bea_storage_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/file/bea_storage_output.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/input/generic_server_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/bea_session.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/generic_server_response.dart';
import 'package:bea_flutter_package/bea_services/utils/key_utils.dart';
import 'package:bea_flutter_package/bea_services/utils/url_utils.dart';
import 'package:dio/dio.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:http_parser/http_parser.dart';
import 'package:mime/mime.dart';
import 'bea_service_manager.dart';
import 'package:path/path.dart' as path;

typedef void OnUploadProgressCallback(int sentBytes, int totalBytes);

class BeaFilesManager{
  final BeaServiceManager bsm;

  String _baseUrl = "";
  FlutterSecureStorage storage;

  BeaFilesManager(this.bsm){
    try{
      if(bsm == null){
        throw new Exception("${this.runtimeType.toString()} not initialized");
      }

      _baseUrl = bsm.getBaseUrl();
      storage = bsm.getBeaStorage();
    }on Exception catch (e){
      print('Initialization ${this.runtimeType.toString()} error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "Costructor",
          text: 'Initialization ${this.runtimeType.toString()} error - $e');
      throw e;
    }
  }

  Future<GenericServerResponse<BeaStorageOutput>> uploadFileBea({GenericServerInput<BeaStorageInput> input, OnUploadProgressCallback onUploadProgress, CancelToken cancelToken}) async {
    GenericServerResponse<BeaStorageOutput> genericServerResponse = new GenericServerResponse<BeaStorageOutput>();
    try{

      if(input == null || input.input == null || input.input.fileToUpload == null){
        throw new Exception("Input not found or not valid.");
      }

      String token = await bsm.getBeaStorage().read(key: KeyUtils.KEY_TOKEN_SESSION);

      File file = input.input.fileToUpload;

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_STORAGE);

      url = url + '?description=${input.input.description}';

      final mimeTypeData = lookupMimeType(input.input.fileToUpload.path, headerBytes: [0xFF, 0xD8]).split('/');

      Map<String, String> headers = {
        "Authorization": "Bearer $token",
        "Content-Type": "application/json",
        "User-agent": "http.agent"
      };

      Dio dio = new Dio();
      FormData formData = FormData.fromMap({
        "file": await MultipartFile.fromFile(file.path, filename:path.basename(file.path), contentType: MediaType(mimeTypeData[0], mimeTypeData[1])),
      });

      dio.options.headers.addAll(headers);
      dio.options.sendTimeout = 5000;
      dio.options.receiveTimeout = 10000;

      var response = await dio.postUri(
          Uri.parse(url),
          data: formData,
          cancelToken: cancelToken,
          onSendProgress: (rec, total) {
            onUploadProgress(rec, total);
      });

      switch(response.statusCode){
        case 200:
          genericServerResponse.data = BeaStorageOutput.fromJson(response.data);
          break;
        case 500:
          BeaError error = BeaError.fromJson(response.data['error']);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }catch(e){
      print('Error to upload file to server BEA');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "uploadFileBea",
          text: 'Error to upload file to server BEA - $e');
      throw e;
    }

    return genericServerResponse;
  }

}

==> bea_flutter_package-2.0.0.tar.gz: lib/bea_services/core/bea_files_manager.dart <==
import 'dart:async';
import 'dart:io';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/error/bea_error.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/file/bea_storage_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/bea_models/base_models/file/bea_storage_output.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/input/generic_server_input.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/bea_session.dart';
import 'package:bea_flutter_package/bea_services/dtos/flutter_models/output/generic_server_response.dart';
import 'package:bea_flutter_package/bea_services/utils/key_utils.dart';
import 'package:bea_flutter_package/bea_services/utils/url_utils.dart';
import 'package:dio/dio.dart';
import 'package:f_logs/model/flog/flog.dart';
import 'package:flutter_secure_storage/flutter_secure_storage.dart';
import 'package:http_parser/http_parser.dart';
import 'package:mime/mime.dart';
import 'bea_service_manager.dart';
import 'package:path/path.dart' as path;

typedef void OnUploadProgressCallback(int sentBytes, int totalBytes);

class BeaFilesManager{
  final BeaServiceManager? bsm;

  String _baseUrl = "";
  FlutterSecureStorage? storage;

  BeaFilesManager(this.bsm){
    try{
      if(bsm == null){
        throw new Exception("${this.runtimeType.toString()} not initialized");
      }

      _baseUrl = bsm!.getBaseUrl();
      storage = bsm!.getBeaStorage();
    }on Exception catch (e){
      print('Initialization ${this.runtimeType.toString()} error');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "Costructor",
          text: 'Initialization ${this.runtimeType.toString()} error - $e');
      throw e;
    }
  }

  Future<GenericServerResponse<BeaStorageOutput>> uploadFileBea({GenericServerInput<BeaStorageInput>? input, OnUploadProgressCallback? onUploadProgress, CancelToken? cancelToken}) async {
    GenericServerResponse<BeaStorageOutput> genericServerResponse = new GenericServerResponse<BeaStorageOutput>();
    try{

      if(input == null || input.input == null || input.input!.fileToUpload == null){
        throw new Exception("Input not found or not valid.");
      }

      String? token = await bsm!.getBeaStorage().read(key: KeyUtils.KEY_TOKEN_SESSION);

      File? file = input.input!.fileToUpload;

      String url = UrlUtils.getUrl(_baseUrl, UrlUtils.URL_STORAGE);

      url = url + '?description=${input.input!.description}';

      final mimeTypeData = lookupMimeType(input.input!.fileToUpload!.path, headerBytes: [0xFF, 0xD8])!.split('/');

      Map<String, String> headers = {
        "Authorization": "Bearer $token",
        "Content-Type": "application/json",
        "User-agent": "http.agent"
      };

      Dio dio = new Dio();
      FormData formData = FormData.fromMap({
        "file": await MultipartFile.fromFile(file!.path, filename:path.basename(file.path), contentType: MediaType(mimeTypeData[0], mimeTypeData[1])),
      });

      dio.options.headers.addAll(headers);
      dio.options.sendTimeout = 5000;
      dio.options.receiveTimeout = 10000;

      var response = await dio.postUri(
          Uri.parse(url),
          data: formData,
          cancelToken: cancelToken,
          onSendProgress: (rec, total) {
            onUploadProgress!(rec, total);
      });

      switch(response.statusCode){
        case 200:
          genericServerResponse.data = BeaStorageOutput.fromJson(response.data);
          break;
        case 500:
          var res = response.data['error'];
          BeaError? error = res == null ? res : BeaError.fromJson(res);
          if (error != null) {
            genericServerResponse.beaError = error;
          } else {
            genericServerResponse.beaError = new BeaError("Unknown Error", 0, "");
          }
          break;
        case 401:
          genericServerResponse.beaSession = new BeaSession(true);
          break;
      }
    }catch(e){
      print('Error to upload file to server BEA');
      FLog.error(
          className: this.runtimeType.toString(),
          methodName: "uploadFileBea",
          text: 'Error to upload file to server BEA - $e');
      throw e;
    }

    return genericServerResponse;
  }

}
